# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.3](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.2...aoe2rec-v0.1.3) - 2025-01-13

### Added

- Add player_id to actions

## [0.1.2](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.1...aoe2rec-v0.1.2) - 2025-01-12

### Other

- update Cargo.lock dependencies

## [0.1.1](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.0...aoe2rec-v0.1.1) - 2025-01-12

### Other

- Add other missing descriptions, do not publish API crate
